@@ -1,4 +1,4 @@
-## ---- echo=FALSE, results="hide"----------------------------------------------
+## ----echo=FALSE, results="hide"-----------------------------------------------
 knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE)
 library(basilisk)
 library(BiocStyle)
@@ -14,14 +14,17 @@ second_env <- BasiliskEnvironment(envname="second_env_name",
     packages=c("scipy=1.9.1", "numpy==1.22.1") 
 )
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  parallel:::setDefaultClusterOptions(setup_strategy = "sequential")
 
 ## -----------------------------------------------------------------------------
+if (.Platform$OS.type != "windows") {
 tmp <- createLocalBasiliskEnv("basilisk-vignette-test",
     packages=c("scikit-learn=1.1.1", "numpy=1.22.1"))
+}
 
-## ---- error=FALSE, message=FALSE----------------------------------------------
+## ----error=FALSE, message=FALSE-----------------------------------------------
+if (.Platform$OS.type != "windows") {
 x <- matrix(rnorm(1000), ncol=10)
 basiliskRun(env=tmp, fun=function(mat) {
     module <- reticulate::import("sklearn.decomposition")
@@ -29,8 +32,10 @@ basiliskRun(env=tmp, fun=function(mat) {
     output <- runner$fit(mat) 
     output$singular_values_
 }, mat = x, testload="scipy.optimize")
+}
 
-## ---- error=FALSE, message=FALSE----------------------------------------------
+## ----error=FALSE, message=FALSE-----------------------------------------------
+if (.Platform$OS.type != "windows") {
 library(reticulate)
 
 # In this case, we'll use reticulate directly to construct our conda
@@ -50,6 +55,7 @@ basiliskRun(env=tmp2, fun=function(mat) {
     norm <- module$norm
     norm$cdf(c(-1, 0, 1))
 }, mat = x, testload="scipy.optimize")
+}
 
 ## -----------------------------------------------------------------------------
 sessionInfo()
